Uses of Interface org.openqa.selenium.server.browserlaunchers.BrowserLauncher (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

## Uses of Interface
org.openqa.selenium.server.browserlaunchers.BrowserLauncher

Packages that use BrowserLauncher
org.openqa.selenium.server | Provides the core Selenium Server classes.
org.openqa.selenium.server.browserlaunchers | Provides classes to launch and kill browsers.
org.openqa.selenium.server.htmlrunner | Provides classes to launch Selenium Core HTML test suites and handle their test results.

Uses of BrowserLauncher in org.openqa.selenium.server

Fields in org.openqa.selenium.server declared as BrowserLauncher
`BrowserLauncher` | `BrowserSessionFactory.BrowserSessionInfo.launcher`

Constructors in org.openqa.selenium.server with parameters of type BrowserLauncher
`BrowserSessionFactory.BrowserSessionInfo(java.lang.String sessionId, java.lang.String browserString, java.lang.String baseUrl, BrowserLauncher launcher, FrameGroupCommandQueueSet session)`

Uses of BrowserLauncher in org.openqa.selenium.server.browserlaunchers

Classes in org.openqa.selenium.server.browserlaunchers that implement BrowserLauncher
`class` | `AbstractBrowserLauncher` Runs the specified command path to start the browser, and kills the process to quit.
`class` | `DestroyableRuntimeExecutingBrowserLauncher` Runs the specified command path to start the browser, and kills the process to quit.
`class` | `Firefox2Launcher`
`class` | `Firefox3Launcher`
`class` | `FirefoxChromeLauncher`
`class` | `FirefoxCustomProfileLauncher`
`class` | `FirefoxLauncher`
`class` | `GoogleChromeLauncher` Browser launcher for Google Chrome.
`class` | `HTABrowserLauncher`
`class` | `InternetExplorerCustomProxyLauncher`
`class` | `InternetExplorerLauncher`
`class` | `KonquerorLauncher`
`class` | `MockBrowserLauncher`
`class` | `OperaCustomProfileLauncher`
`class` | `ProxyInjectionFirefoxCustomProfileLauncher` launcher for Firefox under proxy injection mode In proxy injection mode, the selenium server is a proxy for all traffic from the browser, not just traffic going to selenium-server URLs.
`class` | `ProxyInjectionInternetExplorerCustomProxyLauncher` launcher for IE under proxy injection mode In proxy injection mode, the selenium server is a proxy for all traffic from the browser, not just traffic going to selenium-server URLs.
`class` | `ProxyInjectionSafariCustomProfileLauncher` launcher for Safari under proxy injection mode In proxy injection mode, the selenium server is a proxy for all traffic from the browser, not just traffic going to selenium-server URLs.
`class` | `SafariCustomProfileLauncher`
`class` | `SafariFileBasedLauncher`
`class` | `SafariLauncher`

Methods in org.openqa.selenium.server.browserlaunchers that return BrowserLauncher
`BrowserLauncher` | `BrowserLauncherFactory.getBrowserLauncher(java.lang.String browser, java.lang.String sessionId, RemoteControlConfiguration configuration, BrowserConfigurationOptions browserOptions)` Returns the browser given by the specified browser string

Methods in org.openqa.selenium.server.browserlaunchers that return types with arguments of type BrowserLauncher
`static java.util.Map<java.lang.String,java.lang.Class<? extends BrowserLauncher>>` | `BrowserLauncherFactory.getSupportedLaunchers()`

Method parameters in org.openqa.selenium.server.browserlaunchers with type arguments of type BrowserLauncher
`static void` | `BrowserLauncherFactory.addBrowserLauncher(java.lang.String browser, java.lang.Class<? extends BrowserLauncher> clazz)`

Uses of BrowserLauncher in org.openqa.selenium.server.htmlrunner

Methods in org.openqa.selenium.server.htmlrunner that return BrowserLauncher
`protected BrowserLauncher` | `HTMLLauncher.getBrowserLauncher(java.lang.String browser, java.lang.String sessionId, RemoteControlConfiguration configuration, BrowserConfigurationOptions browserOptions)`

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV NEXT | FRAMES NO FRAMES

Copyright © 2009. All Rights Reserved.